lens
====

``lens`` is a library for exploring data in Pandas DataFrames. It computes
single column summary statistics and estimates the correlation between columns.
We wrote ``lens`` when we realised that the initial steps of acquiring a new
data set were almost formulaic: What data type is in this column? How many null
values are there? Which columns are correlated? What's the distribution of this
value? ``lens`` calculates all this for you.

Installation
------------

``lens`` can be installed from PyPI with ``pip``:

.. code-block:: bash

    pip install lens

Testing
-------

To run the tests, run:

.. code-block:: bash

    py.test --ignore=it

License
-------

``lens`` is licensed under the Apache License, see LICENSE.txt for details.
